Chapter 2. Exploring the Features of XML Résumé Library

# XMLRésuméLibrary: User Guide

Installing and Configuring the Software | Part I. Getting Started | Advanced Features of the XML Résumé Library

# Exploring the Features of XML Résumé Library

### Peter Hutnick

### Mark Miller

#### Edited by

### Bruce Christensen

Copyright © 2002 Peter Hutnick

This chapter provides an overview of the features and usage of the XML Résumé Library, an Open Source, XML based résumé management system, on UNIX systems.

## Formatting an example resume

### Converting to other formats

To get a feel for the power of the XML Résumé Library you should run the example résumés through their paces and see how they turn out after processing. You can do this by renaming the file `example2.xml` to `resume.xml` with the command mv example2.xml resume.xml. Then simply issue the command gmake while connected to the internet. This should generate the files `resume.txt`, `resume.html`, `resume.fo`, and `resume.pdf` — all versions of Alexis Kernighan's résumé.

Installing and Configuring the Software | Part I. Getting Started | Advanced Features of the XML Résumé Library